/////////////////////////// GLOBALS ////////////////////////////

import processing.video.*;

import ch.bildspur.postfx.builder.*;
import ch.bildspur.postfx.pass.*;
import ch.bildspur.postfx.*;

import de.voidplus.leapmotion.*;

LeapMotion leap;
float hx, hy, hz;
boolean isConnect = false;
PImage img;


Movie theMovie;
PostFXSupervisor supervisor;
Threshhold thresh;
BrcosaPass bp;
Gaussian blur;
PGraphics canvas;

// params: 
float param, param2;
boolean isBrcosa = true;
boolean isThresh = false;
boolean isBlur = false;
/////////////////////////// SETUP ////////////////////////////

void setup() {
  size(640, 480, P3D);
  textSize(22);
  fill(0);
  theMovie = new Movie(this, "train.mp4");
  theMovie.loop();

  // create supervisor and load shaders
  supervisor = new PostFXSupervisor(this);
  thresh = new Threshhold();
  bp = new BrcosaPass();
  blur = new Gaussian();
  canvas = createGraphics(width, height, P3D);
  leap = new LeapMotion(this);
}

void draw() {
  // get hand gestures
  for (Hand hand : leap.getHands ()) {
    PVector handPosition = hand.getPosition();
    hx = handPosition.x;
    hy = handPosition.y;
    hz = handPosition.z;

    Finger  fingerIndex = hand.getIndexFinger();
    if (fingerIndex.isExtended()) {
      isConnect = true;
    } else {
      isConnect = false;
    }
  }
  // println(hx);
  // println(hy);

  // draw to canvas
  canvas.beginDraw();
  canvas.image(theMovie, 0, 0);
  canvas.endDraw();

  //apply shaders
  blendMode(BLEND);
  supervisor.render(canvas);

  if (isBrcosa) {
    bp.setParams(hy, 2.0);
    supervisor.pass(bp);
  }
  if (isBlur) {
    blur.setParams(0, hx);
    supervisor.pass(blur);
  }

  if (isThresh) {
    thresh.setParams(hx, 0);
    supervisor.pass(thresh);
  }

  // bring it all together
  supervisor.compose();


  diplayStats();
}


void keyPressed() {
  if (key == '1') {
    isBrcosa = !isBrcosa;
  }

  if (key == '2') {
    isBlur = !isBlur;
  }

  if (key == '3') {
    isThresh = !isThresh;
  }
}


void diplayStats() {
  // stats, to the title window
  float fps = leap.getFrameRate();
  String txt_fps = String.format(getClass().getName()+ " [frame %d]   [fps %6.2f]", frameCount, fps);
  surface.setTitle(txt_fps);
}

void leapOnInit() {
  println("Leap Motion Init");
}
void leapOnConnect() {
  println("Leap Motion Connect");
}
void leapOnFrame() {
  // println("Leap Motion Frame");
}
void leapOnDisconnect() {
  println("Leap Motion Disconnect");
}
void leapOnExit() {
  // println("Leap Motion Exit");
}

void movieEvent(Movie m) {
  m.read();
}