/**
 * BASIC LEAP SETUP
 * https://github.com/nok/leap-motion-processing
 */


import de.voidplus.leapmotion.*;

LeapMotion leap;
float hx, hy, hz;
PVector indexPos, pinkyPos;

boolean isDisplayHand = false;
boolean isDisplayCamera = false;
boolean isConnect = false;

void setup() {
  size(800, 500, P3D);
  background(255);
  colorMode(HSB, 360, 100, 100);

  leap = new LeapMotion(this);
}


void draw() {
  background(0, 0, 100);
  diplayStats();
  if (isDisplayCamera) {
    displayCam();
  }

  // We get hand datas from an ArrayList
  // Various datas are available. See doc for full data list:
  // https://github.com/nok/leap-motion-processing
  for (Hand hand : leap.getHands ()) {
    /** 
     * GET HAND DATA
     */
    PVector handPosition = hand.getPosition();
    hx = handPosition.x;
    hy = handPosition.y;
    hz = handPosition.z;

    if (isDisplayHand) {
      hand.draw();
    }
    
    
    /** GET FINGER DATAS:
     * hand.getThumb();
     * hand.getMiddleFinger();
     * hand.getRingFinger();
     */

    Finger  fingerIndex = hand.getIndexFinger();
    Finger  fingerPink = hand.getPinkyFinger();
    indexPos = fingerIndex.getPosition();
    pinkyPos = fingerPink.getPosition();

    println("Index finger pos: " +indexPos);
    println("Pinky finger pos: " +pinkyPos);
    if (fingerIndex.isExtended()) {
      isConnect = true;
    } else {
      isConnect = false;
  }
  }
  
  if(isConnect) {
  // calculate distance between index & pinky finger
  float fingerDist = dist(indexPos.x, indexPos.y, pinkyPos.x, pinkyPos.y);
  println("Distance between: "+fingerDist);

  // Colour
  int h = (int)map(fingerDist, 90, 270,100, 260);
  fill(h, 100, 100);
  }
  float angleY = map(hx, 0, 1000, 0, 720);
  noStroke();

  // Geometry
  pushMatrix();
  translate(width/2, height/2);
  rotateX(radians(-angleY));
  rotateY(radians(angleY));
  box(hy/3);
  popMatrix();
}



void keyPressed() {
  if (key == 'h') {
    isDisplayHand = !isDisplayHand;
  }
  if (key == 'c') {
    isDisplayCamera = !isDisplayCamera;
  }
  println(isConnect);
}